import type { NodePlopAPI } from 'node-plop';
import { ActionConfig } from 'node-plop';
export declare enum DesignSystemActionType {
    analyzeComponentUsage = "Analyzed component usage",
    switchPrefixes = "Switching design system prefixes"
}
export declare namespace DesignSystemActionConfig {
    interface AnalyzeComponentUsage extends ActionConfig {
        get directory(): string;
    }
    interface SwitchPrefixes extends ActionConfig {
        get filePath(): string;
        get newPrefix(): string;
        get oldCustomPrefix(): string;
    }
}
export declare namespace DesignSystemActions {
    /**
     * Analyses the contents of the directory and reports component usage etc.
     * @param directory - The directory to analyze.
     *
     * @public
     */
    const analyzeComponentUsage: (directory: string) => void;
    /**
     * Switches all design system prefixes found in the given file to a new prefix, ie. templates, css rules, markdown etc.
     * @param filePath - The file path to operate on.
     * @param newPrefix - The new design system prefix to switch to.
     * @param oldCustomPrefix - Any custom prefix to search for in addition to the default ones.
     *
     * @public
     * @remarks
     * The search pattern avoids changing any imports or file references that may match.
     */
    const switchPrefixes: (filePath: string, newPrefix: string, oldCustomPrefix?: string) => void;
}
/**
 * Add design system related actions to plop
 * @param plop - The plop api
 *
 * @public
 */
export declare const setActionTypes: (plop: NodePlopAPI) => void;
//# sourceMappingURL=designSystem.d.ts.map