"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWorkspaceGenerator = void 0;
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const utils_1 = require("../../../utils");
const fileSystem_1 = require("../../actions/fileSystem");
const npm_1 = require("../../actions/npm");
const seed_1 = require("../../actions/seed");
const messages_1 = require("../../messages");
const normalizers_1 = require("../../normalizers");
const filesystem_1 = tslib_1.__importDefault(require("../../prompts/filesystem"));
const workspace_1 = tslib_1.__importDefault(require("../../prompts/workspace"));
const tasks_1 = require("../../tasks");
const applyRuntimeArgs = (prevAns = {}) => {
    if (!prevAns.workspaceDirectory) {
        prevAns.workspaceDirectory = utils_1.argv.workspaceDirectory || utils_1.env.GENESISLCAP_WORKSPACE_DIRECTORY;
    }
    if (!prevAns.workspaceName) {
        prevAns.workspaceName = utils_1.argv.workspaceName || utils_1.env.GENESISLCAP_WORKSPACE_NAME;
    }
    if (prevAns.forceOverwrite === undefined) {
        prevAns.forceOverwrite = utils_1.argv.forceOverwrite || utils_1.env.GENESISLCAP_FORCE_OVERWRITE;
    }
    return prevAns;
};
exports.createWorkspaceGenerator = {
    description: (0, messages_1.generatorDescription)('Create a local workspace to house a set of applications.'),
    prompts(inquirer, prevAns = {}) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            prevAns = applyRuntimeArgs(prevAns);
            const seedList = yield (0, tasks_1.downloadSeedList)('workspaces');
            let { workspaceDirectory, workspaceName, workspaceSeed } = yield (0, workspace_1.default)(inquirer, prevAns, seedList);
            workspaceSeed = yield (0, normalizers_1.seedSelectionNormalizer)(inquirer, workspaceSeed);
            const { forceOverwrite } = yield (0, filesystem_1.default)(inquirer, prevAns, workspaceDirectory, workspaceName);
            return {
                workspaceDirectory,
                workspaceName,
                workspaceSeed,
                forceOverwrite,
            };
        });
    },
    actions: (answers) => [
        {
            type: fileSystem_1.FileSystemActionType.createPath,
            get answerKey() {
                return 'targetDirectory';
            },
            get paths() {
                return [answers.workspaceDirectory, answers.workspaceName];
            },
        },
        {
            type: fileSystem_1.FileSystemActionType.createDirectory,
            get directory() {
                return answers.targetDirectory;
            },
        },
        {
            type: seed_1.SeedActionType.create,
            get directory() {
                return answers.targetDirectory;
            },
            get seed() {
                return answers.workspaceSeed;
            },
        },
        `Installing dependencies`,
        {
            type: npm_1.NpmActionType.install,
            get directory() {
                return path_1.default.join(answers.targetDirectory, '.genx');
            },
        },
    ],
};
